measuretools.report_meter_distribution_as_string
================================================

.. autofunction:: abjad.tools.measuretools.report_meter_distribution_as_string.report_meter_distribution_as_string
